==> pkrcomponents-4.2.2-py3-none-any.whl: pkrcomponents/components/players/player_hand_stats.py <==
from attrs import define, Factory, field
from attrs.validators import instance_of
import csv
from pkrcomponents.components.players.street_hand_stats import preflop, postflop, general


@define
class PlayerHandStats:
    """
    This class represents the statistics of a player's hand in a poker game

    Methods:
        reset: Resets all stats
    """
    # A. Preflop stats
    preflop = field(
        default=Factory(preflop.PreflopPlayerHandStats),
        metadata={'description': 'Preflop player stats for a hand'},
        validator=instance_of(preflop.PreflopPlayerHandStats))
    flop = field(
        default=Factory(postflop.PostflopPlayerHandStats),
        metadata={'description': 'Flop player stats for a hand'},
        validator=instance_of(postflop.PostflopPlayerHandStats))
    turn = field(
        default=Factory(postflop.PostflopPlayerHandStats),
        metadata={'description': 'Turn player stats for a hand'},
        validator=instance_of(postflop.PostflopPlayerHandStats))
    river = field(
        default=Factory(postflop.PostflopPlayerHandStats),
        metadata={'description': 'River player stats for a hand'},
        validator=instance_of(postflop.PostflopPlayerHandStats))
    general = field(
        default=Factory(general.GeneralPlayerHandStats),
        metadata={'description': 'General player stats for a hand'},
        validator=instance_of(general.GeneralPlayerHandStats))

    def __attrs_post_init__(self):
        self.preflop.reset()
        self.flop.reset()
        self.turn.reset()
        self.river.reset()
        self.general.reset()

    def reset(self):
        """
        Resets the statistics
        """
        for attribute in self.__attrs_attrs__:
            # noinspection PyTypeChecker
            if isinstance(attribute.default, Factory):
                # noinspection PyUnresolvedReferences
                setattr(self, attribute.name, attribute.default.factory())
            else:
                setattr(self, attribute.name, attribute.default)

#     @classmethod
#     def generate_description_file(cls):
#         """
#         Generate a csv file to describe data from class
#         """
#         with open('hand_stats_description.csv', 'w', newline='') as csvfile:
#             fieldnames = ['name', 'default', 'description', 'type']
#             writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
#
#             writer.writeheader()
#             for attribute in cls.__attrs_attrs__:
#                 row = {
#                     'name': attribute.name,
#                     'default': attribute.default if not isinstance(attribute.default, Factory)
#                     else attribute.default.factory(),
#                     'description': attribute.metadata.get('description', 'No description'),
#                     'type': attribute.metadata.get('type', 'No type')
#                 }
#                 writer.writerow(row)
#         print("CSV file 'class_description.csv' generated successfully.")
#
#
# if __name__ == '__main__':
#     HandStats.generate_description_file()

==> pkrcomponents-4.4.8-py3-none-any.whl: pkrcomponents/components/players/player_hand_stats.py <==
import csv
import pandas as pd

from attrs import define, Factory, field
from attrs.validators import instance_of
from pkrcomponents.components.players.street_hand_stats import preflop, postflop, general
from pkrcomponents.components.players.street_hand_stats.base import StreetHandStatsBase


@define
class PlayerHandStats(StreetHandStatsBase):
    """
    This class represents the statistics of a player's hand in a poker game

    Methods:
        reset: Resets all stats
    """
    # A. Preflop stats
    preflop = field(
        default=Factory(preflop.PreflopPlayerHandStats),
        metadata={'description': 'Preflop player stats for a hand'},
        validator=instance_of(preflop.PreflopPlayerHandStats))
    flop = field(
        default=Factory(postflop.PostflopPlayerHandStats),
        metadata={'description': 'Flop player stats for a hand'},
        validator=instance_of(postflop.PostflopPlayerHandStats))
    turn = field(
        default=Factory(postflop.PostflopPlayerHandStats),
        metadata={'description': 'Turn player stats for a hand'},
        validator=instance_of(postflop.PostflopPlayerHandStats))
    river = field(
        default=Factory(postflop.PostflopPlayerHandStats),
        metadata={'description': 'River player stats for a hand'},
        validator=instance_of(postflop.PostflopPlayerHandStats))
    general = field(
        default=Factory(general.GeneralPlayerHandStats),
        metadata={'description': 'General player stats for a hand'},
        validator=instance_of(general.GeneralPlayerHandStats))

    def __attrs_post_init__(self):
        self.preflop.reset()
        self.flop.reset()
        self.turn.reset()
        self.river.reset()
        self.general.reset()

    def to_dataframe(self) -> pd.DataFrame:
        """
        Converts the object to a pandas DataFrame
        """
        street_names = ['general', 'preflop', 'flop', 'turn', 'river']
        data_frames = [getattr(self, street_name).to_dataframe() for street_name in street_names]
        # Join all dataframes with the usage of street_names as keys
        df = pd.concat(data_frames, axis=1, keys=street_names)
        # Modify the column names by adding the street name as prefix to the current column names
        df.columns = [f'{street_name}_{column_name}' for street_name, column_name in df.columns]
        return df



if __name__ == '__main__':
    PlayerHandStats.generate_description_file()
